function [f,g,gr] = delay(z)
%
% In general
% f(j)  - f_j(z) in sum_{j=1}^m f_j(z) A_j
% g(j)  - f_j'(z) (complex differentiation, e.g., (z^j)' = j*(z^{j-1}))
% gr(j,:) - partial derivatives of Re f_j(z)
%				gr(j,1) - d (Re f_j)(z)/ d Re(z)   
%				gr(j,2) - d (Re f_j)(z) / d Im(z)
%
%
%
% In this particular case the matrix-valued function is
%   F(z) = zI - A_0 - A_1 e^{-z} - A_2 e^{-3z}
% Thus
%   f(1) = z, g(1) = 1
%	gr(1,1) = 1, gr(1,2) = 0
%
%	f(2) = -1, g(2) = 0 
%	gr(2,1) = gr(2,2) = 0
%
%	f(3) = -e^{-z}, g(3) = e^{-z}
%	gr(3,1) = e^{-Re z}cos(Im z) gr(3,2) = e^{-Re z} sin(Im z)
%
%	f(4) = -e^{-3z}, g(4) = 3e^{-3z}
%	gr(4,1) = 3e^{-3Re z} cos(3Im z)  gr(4,2) = 3e^{-3Re z} sin(3 Im z)
%



tau(1) = 1;
tau(2) = 3;
nd = 2;




f(1) = z;
f(2) = -1;

for j = 1:nd
	f(j+2) = -exp(-z*tau(j));
end





g(1) = 1;
g(2) = 0;
for j = 1:2
	g(j+2) = tau(j)*exp(-z*tau(j));
end





gr(1,1) = 1;
gr(1,2) = 0;

gr(2,1) = 0;
gr(2,2) = 0;

for j = 1:nd
	gr(j+2,1) = tau(j)*exp(-real(z)*tau(j))*cos(imag(z)*tau(j));
	gr(j+2,2) = tau(j)*exp(-real(z)*tau(j))*sin(imag(z)*tau(j));
end

			 
return;