function [f,x,xvec,fvec] = eigopt_constrained(funname, c, pars)

x = pars.x0;

if (isfield(pars,'gamma'))
	gamma = pars.gamma;
else	
	gamma = 2;
end

if (isfield(pars,'tol'))
	tol = pars.tol;
else
	tol = 10^-4;
end

if (isfield(pars,'maxit'))
    maxit = pars.maxit;
else
    maxit = 20000;
end

if (isfield(pars,'verbose'))
    verbose = pars.verbose;
else
    verbose = 0;
end

iter = 1;
nc = norm(c);
xvec = x;
fvec = c'*x;
xnew = [];

if verbose
    plot(x(1),x(2),'*r');
end

while ((iter == 1) || (norm(xnew - x) > tol))


	if (iter ~= 1)
		x = xnew;
	end


	[f,g] = feval(funname,x,pars);

	xnew = x + (1/gamma)*(sqrt(norm(g)^2 - 2*gamma*f)*c - g);


	if norm(xnew) > 1e+50
		xnew = inf(length(xnew),1);
		f = inf;
		return;
	end			
			 
	
	xvec = [xvec xnew];
	fvec = [fvec c'*xnew];
			
	iter = iter + 1;
    
    if verbose
        plot(xnew(1),xnew(2),'*g');
        pause(0.001);
        plot(xnew(1),xnew(2),'*r');
    end
    
    if iter > maxit
        display('eigopt-constrained, could not converge after max # iterations')
        warning(['@rvb: max number of ',num2str(maxit),' iteration reached.']);
        break;
    end
       
end


x = xnew;
f = c'*x;

return;