function [f, g] = fdist_instab(omega,pars)

%% defaults
n_svd = 200;

A = pars.A;
wA = pars.wA;
sigma = pars.sigma;

z = sigma + i*omega;

%%%%%%%%%%%%%%%%
% Evaluate the matrix polynomial at z
%				also the derivative of the matrix polynomial
%%%%%%%%%%%%%%%%
n = size(A{1},2);
m = length(A);


if pars.steig >= 0
	Apoly = A{1};
	Apolyd = A{2};

	for k = 2:m
		Apoly = Apoly + A{k}*z^(k-1);
		if (k >= 3)
			Apolyd = Apolyd + (k-1)*A{k}*z^(k-2);
		end
	end
	% And the corresponding scaling
	%			also the derivative of the scaling
	w = 0;
	wd = 0;

	if pars.steig
		m = 1;
	end

	for k = 1:m
		if wA(k) ~= inf
			w = w + abs(z^(k-1))/wA(k);
			if (k >= 2)
				wd = wd + (k-1)*abs(z^(k-2))/wA(k);
			end
		end
	end
	%%%%%%%%%%%%%%%%%
	%%%%%%%%%%%%%%%%%
else
	[f,g,gr] = feval(pars.funname,z);

	Apoly = A{1}*f(1);
	Apolyd = A{1}*g(1);

	for k = 2:m
		Apoly = Apoly + A{k}*f(k);
		Apolyd = Apolyd + A{k}*g(k);
	end

	if wA(1) ~= inf
		w = abs(f(1))/wA(1);
		wdc = (  real(f(1))*gr(1,2) + imag(f(1))*gr(1,1)  )/(wA(1)*abs(f(1)));
	else
		w = 0;
		wdc = 0;
	end

	for k = 2:m
		if wA(k) ~= inf
			w = w + abs(f(k))/wA(k); 
			wdc = wdc + (  real(f(k))*gr(k,2) + imag(f(k))*gr(k,1)  )/(wA(k)*abs(f(k)));
		end
	end

end


if n < n_svd
	[SU,SS,SV] = svd(Apoly);
	s = SS(n,n);
	v = SV(:,n);
	u = SU(:,n);
else
	[v,s] = eigs(Apoly'*Apoly,1,0);
	s = sqrt(s);
	u = (Apoly*v)/s;
end


f = s/w;
                 
				 
if pars.steig >= 0
	g = -imag(u'*Apolyd*v)/w - (s*wd*omega)/(w^2*abs(z));
else
	g = -imag(u'*Apolyd*v)/w - (s*wdc)/w^2;		
end
