function [f, g] = fpsa(x,pars)

%% defaults
n_svd = 200;

A = pars.A;
wA = pars.wA;

z = x(1)+i*x(2);


%%%%%%%%%%%%%%%%
% Evaluate the matrix polynomial at z
%				also the derivative of the matrix polynomial
%%%%%%%%%%%%%%%%

n = size(A{1},2);
m = length(A);

if pars.steig >= 0
	Apoly = A{1};
	Apolyd = A{2};

	for k = 2:m
		Apoly = Apoly + A{k}*z^(k-1);
		if (k >= 3)
			Apolyd = Apolyd + (k-1)*A{k}*z^(k-2);
		end
	end

	% And the corresponding scaling
	%			also the derivative of the scaling
	w = 0;
	wd = 0;

	if pars.steig
		m = 1;
	end

	for k = 1:m
		if wA(k) ~= inf
			w = w + abs(z^(k-1))/wA(k);
			if (k >= 2)
				wd = wd + (k-1)*abs(z^(k-2))/wA(k);
			end
		end
	end

	%%%%%%%%%%%%%%%%%
	%%%%%%%%%%%%%%%%%
else
	[f,g,gr] = feval(pars.funname,z);

	Apoly = A{1}*f(1);
	Apolyd = A{1}*g(1);

	for k = 2:m
		Apoly = Apoly + A{k}*f(k);
		Apolyd = Apolyd + A{k}*g(k);
	end

	if wA(1) ~= inf
		w = abs(f(1))/wA(1);
		% wdr is the derivative of w w.r.t. Re(z)
		% wdc is the derivative of w w.r.t. Im(z)
		wdr = (  real(f(1))*gr(1,1) - imag(f(1))*gr(1,2)  )/(abs(f(1))*wA(1));
		wdc = (  real(f(1))*gr(1,2) + imag(f(1))*gr(1,1)  )/(abs(f(1))*wA(1));
	else
		w = 0;
		wdr = 0;
		wdc = 0;
	end

	for k = 2:m
		if wA(k) ~= inf
			w = w + abs(f(k))/wA(k); 
			wdr = wdr + (  real(f(k))*gr(k,1) - imag(f(k))*gr(k,2)  )/(abs(f(k))*wA(k));
			wdc = wdc + (  real(f(k))*gr(k,2) + imag(f(k))*gr(k,1)  )/(abs(f(k))*wA(k));
		end
	end
end



%%%%%%%%%%%%%%%%%%
% Evaluate the eigenvalue function
%%%%%%%%%%%%%%%%%%
if n < n_svd
	[SU,SS,SV] = svd(Apoly);
	eigval = SS(n,n)^2;
	v = SV(:,n);
else
	[v,eigval] = eigs(Apoly'*Apoly,1,'SM');
end

					  
					  
f = eigval - pars.epsln^2*w^2;								  
%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%

				  
				  
%%%%%%%%%%%%%%%%%%
% Evaluate the derivative of the eigenvalue function
%%%%%%%%%%%%%%%%%%		

if pars.steig >= 0
	g = [  real(v'* [Apoly'*Apolyd + Apolyd'*Apoly]	*v)   -		2*pars.epsln^2*w*wd*x(1)/abs(z);
		real(v'* [Apoly'*Apolyd*i - Apolyd'*Apoly*i] *v)	-		2*pars.epsln^2*w*wd*x(2)/abs(z) ];
else
	g = [  real(v'* [Apoly'*Apolyd + Apolyd'*Apoly]	*v)   -		2*pars.epsln^2*w*wdr;
		real(v'* [Apoly'*Apolyd*i - Apolyd'*Apoly*i] *v)	-		2*pars.epsln^2*w*wdc ];
end

			 
return;