function [minsval,minsvec] = ps(A,wA,z,steig,funname)
% singular value computation for pseudospectrum of a matrix polynomial


%% defaults
n_svd = 200;


%%%%%%%%%%%%%%%%
% Evaluate the matrix polynomial at z
%%%%%%%%%%%%%%%%

if steig >= 0 % polynomial or standard eigenvalue problem
	if iscell(A)
		Apoly = A{1};
		n = size(A{1},2);
		m = length(A);
	else
		n = size(A,1);
		Apoly = A - z*eye(n);
		m = 1;
	end

	for k = 2:m
		Apoly = Apoly + A{k}*z^(k-1);
	end	


	if steig
		m = 1;
	end


	% And the corresponding scaling
	w = 0;
	for k = 1:m
		if wA(k) ~= inf
			w = w + abs(z^(k-1))/wA(k);
		end
	end
	%%%%%%%%%%%%%%%%%
	%%%%%%%%%%%%%%%%%
else % nonlinear eigenvalue problem
	n = size(A{1},2);
	m = length(A);
	[f,~,~] = feval(funname,z);

	Apoly = A{1}*f(1);
	for k = 2:m
		Apoly = Apoly + A{k}*f(k);
	end	

	% And the corresponding scaling
	w = 0;
	for k = 1:m
		if wA(k) ~= inf
			w = w + abs(f(k))/wA(k);
		end
	end
	%%%%%%%%%%%%%%%%%
	%%%%%%%%%%%%%%%%%
end


        
%%%%%%%%%%%%%%%%%%
% Smallest singular value of analytic matrix-valued function at z
%%%%%%%%%%%%%%%%%%
if n < n_svd
	[~,S,V] = svd(full(Apoly));
	svdmin = S(n,n);
	minsvec = V(:,n);
else
    [minsvec,svdmin] = eigs(Apoly'*Apoly,1,0);
    svdmin = sqrt(svdmin);
end

minsval = svdmin/w;
%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%


return;

